SoCo 0.25 Release Notes
***********************

**SoCo 0.25.0** (Released on 2021-12-03), contains new features as well as internal improvements.

Please see the GitHub release for further details:
https://github.com/SoCo/SoCo/releases/tag/v0.25.0